@@ -9,7 +9,7 @@ use Data::Dmp;
 # AUTHOR
 our $DATE = '2021-09-06'; # DATE
 our $DIST = 'Data-Sah-Coerce-perl-To_date-From_str-natural'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # TMP
 our $time_zone = 'UTC';
@@ -63,7 +63,7 @@ Data::Sah::Coerce::perl::To_date::From_str::natural - Coerce date from string pa
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Coerce::perl::To_date::From_str::natural (from Perl distribution Data-Sah-Coerce-perl-To_date-From_str-natural), released on 2021-09-06.
+This document describes version 0.012 of Data::Sah::Coerce::perl::To_date::From_str::natural (from Perl distribution Data-Sah-Coerce-perl-To_date-From_str-natural), released on 2021-09-06.
 
 =head1 SYNOPSIS
 
@@ -88,8 +88,14 @@ Source repository is at L<https://github.com/perlancar/perl-Data-Sah-Coerce-perl
 
 =head1 SEE ALSO
 
+L<DateTime::Format::Natural> - the backend used to parse date strings.
+
+L<Data::Sah::Coerce::perl::To_date::From_str::natural_utc>
+
 L<Data::Sah::Coerce::perl::To_date::From_str::natural_local>
 
+L<Data::Sah::Coerce::perl::To_date::From_str::flexible>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
